@@ -24,8 +24,8 @@ type FileContent struct {
 }
 
 func init() {
-	defaultWebDocsPath := fmt.Sprintf("%s/checkdocs", projectRoot)
-	rootCmd.Flags().StringVar(&webPath, "web-path", defaultWebDocsPath, "The path to generate web into, defaults to ./checkdocs")
+	defaultWebDocsPath := fmt.Sprintf("%s/docs/checks", projectRoot)
+	rootCmd.Flags().StringVar(&webPath, "web-path", defaultWebDocsPath, "The path to generate web into, defaults to ./docs/checks")
 }
 
 func main() {
@@ -42,10 +42,6 @@ var rootCmd = &cobra.Command{
 	RunE: func(cmd *cobra.Command, args []string) error {
 
 		fileContents := getSortedFileContents()
-		if err := generateChecksFiles(fileContents); err != nil {
-			return err
-		}
-
 		if err := generateExtensionCodeFile(fileContents); err != nil {
 			return err
 		}
@@ -73,7 +69,6 @@ func getSortedFileContents() []*FileContent {
 			Checks:   checks,
 		})
 	}
-	generateNavIndexFile(fileContents)
 	return fileContents
 }
 
