@@ -7,6 +7,7 @@ import (
 	"strings"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
+	"github.com/hashicorp/hcl/v2"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/metrics"
 
@@ -14,19 +15,19 @@ import (
 	"github.com/zclconf/go-cty/cty"
 )
 
-type ModuleInfo struct {
+type ModuleDefinition struct {
 	Name       string
 	Path       string
 	Definition block.Block
-	Blocks     block.Blocks
+	Modules    []block.Module
 }
 
 // LoadModules reads all module blocks and loads the underlying modules, adding blocks to e.moduleBlocks
-func (e *Evaluator) loadModules(stopOnHCLError bool) []*ModuleInfo {
+func (e *Evaluator) loadModules(stopOnHCLError bool) []*ModuleDefinition {
 
 	blocks := e.blocks
 
-	var modules []*ModuleInfo
+	var moduleDefinitions []*ModuleDefinition
 
 	expanded := e.expandBlocks(blocks.OfType("module"))
 
@@ -34,20 +35,19 @@ func (e *Evaluator) loadModules(stopOnHCLError bool) []*ModuleInfo {
 		if moduleBlock.Label() == "" {
 			continue
 		}
-		module, err := e.loadModule(moduleBlock, stopOnHCLError)
+		moduleDefinition, err := e.loadModule(moduleBlock, stopOnHCLError)
 		if err != nil {
 			_, _ = fmt.Fprintf(os.Stderr, "WARNING: Failed to load module: %s\n", err)
 			continue
 		}
-		metrics.Add(metrics.ModuleBlocksLoaded, len(module.Blocks))
-		modules = append(modules, module)
+		moduleDefinitions = append(moduleDefinitions, moduleDefinition)
 	}
 
-	return modules
+	return moduleDefinitions
 }
 
 // takes in a module "x" {} block and loads resources etc. into e.moduleBlocks - additionally returns variables to add to ["module.x.*"] variables
-func (e *Evaluator) loadModule(b block.Block, stopOnHCLError bool) (*ModuleInfo, error) {
+func (e *Evaluator) loadModule(b block.Block, stopOnHCLError bool) (*ModuleDefinition, error) {
 
 	if b.Label() == "" {
 		return nil, fmt.Errorf("module without label at %s", b.Range())
@@ -102,11 +102,11 @@ func (e *Evaluator) loadModule(b block.Block, stopOnHCLError bool) (*ModuleInfo,
 	debug.Log("Loaded module '%s' (requested at %s)", modulePath, b.Range())
 	metrics.Add(metrics.ModuleLoadCount, 1)
 
-	return &ModuleInfo{
+	return &ModuleDefinition{
 		Name:       b.Label(),
 		Path:       modulePath,
 		Definition: b,
-		Blocks:     blocks,
+		Modules:    []block.Module{block.NewHCLModule(e.projectRootPath, modulePath, blocks)},
 	}, nil
 }
 
@@ -116,6 +116,7 @@ func getModuleBlocks(b block.Block, modulePath string, blocks *block.Blocks, sto
 		return fmt.Errorf("failed to load module %s: %w", b.Label(), err)
 	}
 
+	moduleCtx := block.NewContext(&hcl.EvalContext{}, nil)
 	for _, file := range moduleFiles {
 		fileBlocks, err := LoadBlocksFromFile(file)
 		if err != nil {
@@ -129,7 +130,7 @@ func getModuleBlocks(b block.Block, modulePath string, blocks *block.Blocks, sto
 			debug.Log("Added %d blocks from %s...", len(fileBlocks), fileBlocks[0].DefRange.Filename)
 		}
 		for _, fileBlock := range fileBlocks {
-			*blocks = append(*blocks, block.NewHCLBlock(fileBlock, nil, b))
+			*blocks = append(*blocks, block.NewHCLBlock(fileBlock, moduleCtx, b))
 		}
 	}
 	return nil
