@@ -30,4 +30,10 @@ func OptionSkipDownloaded() Option {
 	return func(p *Parser) {
 		p.skipDownloaded = true
 	}
+}
+
+func OptionWithExcludePaths(paths []string) Option {
+	return func(p *Parser) {
+		p.excludePaths = paths
+	}
 }
\ No newline at end of file
