@@ -26,13 +26,34 @@ resource "aws_network_acl_rule" "my-rule" {
   cidr_block     = "0.0.0.0/0"
 }`,
 			mustIncludeResultCode: expectedCode,
-		}, {
+		},
+		{
 			name: "check aws_network_acl_rule ingress on 0.0.0.0/0 implied egress",
 			source: `
 resource "aws_network_acl_rule" "my-rule" {
   protocol       = "all"
   rule_action    = "allow"
   cidr_block     = "0.0.0.0/0"
+}`,
+			mustIncludeResultCode: expectedCode,
+		},
+		{
+			name: "check aws_network_acl_rule ingress on 0.0.0.0/0 implied egress with -1 string",
+			source: `
+resource "aws_network_acl_rule" "my-rule" {
+  protocol       = "-1"
+  rule_action    = "allow"
+  cidr_block     = "0.0.0.0/0"
+}`,
+			mustIncludeResultCode: expectedCode,
+		},
+		{
+			name: "check aws_network_acl_rule ingress on 0.0.0.0/0 implied egress with -1",
+			source: `
+resource "aws_network_acl_rule" "my-rule" {
+  protocol       = -1
+  rule_action    = "allow"
+  cidr_block     = "0.0.0.0/0"
 }`,
 			mustIncludeResultCode: expectedCode,
 		},
