@@ -10,7 +10,6 @@ import (
 	"github.com/aquasecurity/tfsec/pkg/provider"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/cidr"
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 
@@ -58,7 +57,7 @@ resource "openstack_fw_rule_v1" "rule_1" {
 		RequiredTypes:   []string{"resource"},
 		RequiredLabels:  []string{"openstack_fw_rule_v1"},
 		DefaultSeverity: severity.Medium,
-		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, _ block.Module) {
 
 			if resourceBlock.GetAttribute("enabled").IsFalse() {
 				return
