@@ -7,6 +7,8 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/custom"
+
 	"github.com/aquasecurity/tfsec/pkg/result"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
@@ -20,6 +22,8 @@ type ExternalScanner struct {
 	internalOptions []scanner.Option
 }
 
+const customChecksDir = ".tfsec"
+
 func NewExternalScanner(options ...Option) *ExternalScanner {
 	external := &ExternalScanner{}
 	for _, option := range options {
@@ -33,6 +37,10 @@ func (t *ExternalScanner) AddPath(path string) error {
 	if err != nil {
 		return err
 	}
+	customCheckDir := filepath.Join(filepath.Dir(path), customChecksDir)
+	if err := custom.Load(customCheckDir); err != nil {
+		return err
+	}
 	t.paths = append(t.paths, abs)
 	return nil
 }
@@ -71,6 +79,8 @@ func rewriteIds(results []result.Result) []result.Result {
 	for _, r := range results {
 		if avd, ok := idMap[r.RuleID]; ok {
 			updatedResults = append(updatedResults, *r.WithRuleID(avd))
+		} else {
+			updatedResults = append(updatedResults, r)
 		}
 	}
 	return updatedResults
