@@ -1,6 +1,9 @@
 package externalscan
 
-import "github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
+import (
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/debug"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
+)
 
 type Option func(e *ExternalScanner)
 
@@ -9,3 +12,9 @@ func OptionIncludePassed() Option {
 		e.internalOptions = append(e.internalOptions, scanner.OptionIncludePassed())
 	}
 }
+
+func OptionDebugEnabled(debugEnabled bool) Option {
+	return func(e *ExternalScanner) {
+		debug.Enabled = debugEnabled
+	}
+}
